Learn R Programming

blmeco (version 1.0)

anoctua: Presence-absence data of Little owls in nest boxes

Description

The data contains presence-absence data of Little owls in nest boxes and elevation

Usage

data(anoctua)

Arguments

References

Gottschalk, T, Ekschmitt, K., Volters, V. (2011) Efficient placement of nest boxes for the little owl (Athene noctua). The Journal of Raptor Research 45: 1-14

Examples

Run this code
data(anoctua)

Run the code above in your browser using DataLab