Learn R Programming

blmeco (version 1.0)

blackstork: Breeding success of Black storks in Latvia

Description

The data set contains number of nestlings in Blackstork (Ciconia nigra) nests.

Usage

data(blackstork)

Arguments

source

The data is property of Maris Stradz. Attention, this is a non-random subselection of the data available. Please, contact Maris Stradz, if you have interest in the whole data set. mstrazds@latnet.lv

Examples

Run this code
data(blackstork)

Run the code above in your browser using DataLab