The aim of the study was to look at the corticosterone increase due to the corticosterone implants. In each brood one or two nestlings were implanted with a corticosterone-implant and one or two nestlings with a placebo-implant (variable Implant). Blood samples were taken just before implantation (day 1), 2 and 20 days after implantation. In total we have 287 measurements of 151 individuals (variable Ring) of 54 broods.
data(cortbowl)A data frame with 287 observations on the following 6 variables.
Broodid of brood
Ringid of individual
Implanta factor with levels C P; treatment: C=corticosterone treatment, P=placebo
Ageage of nestling in days
daysthe day of the blood sample
totCortcorticosterole measurement in the blood sample
Almasi, B., Roulin, A., Jenni-Eiermann, S., Breuner, C.W., Jenni, L., 2009. Regulation of free corticosterone and CBG capacity under different environmental conditions in altricial nestlings. Gen. Comp. Endocr. 164, 117-124.
# NOT RUN {
data(cortbowl)
# }
Run the code above in your browser using DataLab