Learn R Programming

blmeco (version 1.0)

roostingsiteuse: Roosting site use by little owls

Description

Locations of roosting sites of little owls obtained by telemetry data

Usage

data(roostingsiteuse)

Arguments

References

Bock, A., Naef-Daenzer, B., Keil, H., Korner-Nievergelt, F., Perrig, M., Grueebler, M. U. (2013) Roost site selection by Little Owls Athene noctua in relation to environmental conditions and life history stages. Ibis 155: 847-856.

Examples

Run this code
data(roostingsiteuse)

Run the code above in your browser using DataLab