Learn R Programming

blmeco (version 1.0)

spermdepletion: Sperm depletion data in a hermaphrodite sea slug

Description

Data of experiment 1 in Anthes et al. (2014) to measure the depletion rate of sperms in a hermaphrodite sea slug.

Usage

data(spermdepletion)

Arguments

References

Anthes N, Werminghausen J, Lange R (2014) Large donors transfer more sperm, but depletion is faster in a promiscuous hermaphrodite. Behavioural Ecology and Sociobiology 68: 477-483.

Examples

Run this code
data(spermdepletion)

Run the code above in your browser using DataLab