Learn R Programming

blmeco (version 1.0)

wingbowl: Growth rate data of Barn owl nestlings and corticosterone

Description

The data contains wing length measurements of Barn owl nestlings that were either treated with a corticosterone or a placebo implant.

Usage

data(wingbowl)

Arguments

References

AlmaisB, Roulin A, Korner-Nievergelt F, Jenni-Eiermann S, Jenni L (2012) Coloration signals the ability to cope with elevated stress hormones: effects of corticosterone on growth of barn owls are associated with melanism. JOurnal of Evolutionary Biology 25: 1189-1199

Examples

Run this code
data(wingbowl)

Run the code above in your browser using DataLab