Learn R Programming

blmeco (version 1.0)

yellow_bellied_toad: Site-occupancy data for Yellow-bellied toads

Description

Site-occupancy data indicating whether Yellow-bellied toads (Bombina variegata) were observed (1; 0 otherwise) in a given site and during a given visit.

Usage

data(yellow_bellied_toad)

Arguments

source

The data is provided by Isabelle Floess, Landschaft und Gewaesser, Kanton Aargau.

Examples

Run this code
data(yellow_bellied_toad)

Run the code above in your browser using DataLab