Learn R Programming

blmeco (version 1.0)

cortbowl: stress hormone data of nestling barn owls which were either treated with a corticosterone-implant or with a placebo-implant as control

Description

The aim of the study was to look at the corticosterone increase due to the corticosterone implants. In each brood one or two nestlings were implanted with a corticosterone-implant and one or two nestlings with a placebo-implant (variable Implant). Blood samples were taken just before implantation (day 1), 2 and 20 days after implantation. In total we have 287 measurements of 151 individuals (variable Ring) of 54 broods.

Usage

data(cortbowl)

Arguments

References

Almasi, B., Roulin, A., Jenni-Eiermann, S., Breuner, C.W., Jenni, L., 2009. Regulation of free corticosterone and CBG capacity under different environmental conditions in altricial nestlings. Gen. Comp. Endocr. 164, 117-124.

Examples

Run this code
data(cortbowl)

Run the code above in your browser using DataLab